@@ -54,9 +54,9 @@ sub DESTROY {
   return if $self->{last_msg} eq ACESERV_MSGKILL;
   $self->_send_msg('quit');
 # Is _recv_msg() bringing things down in flames?  Maybe!
-#    my ($msg,$body) = $self->_recv_msg('strip');
-#  warn "Did not get expected ACESERV_MSGKILL message, got $msg instead" 
-#    if defined($msg) and $msg ne ACESERV_MSGKILL;
+  my ($msg,$body) = $self->_recv_msg('strip');
+  warn "Did not get expected ACESERV_MSGKILL message, got $msg instead" 
+    if defined($msg) and $msg ne ACESERV_MSGKILL;
 }
 
 sub encore { return shift->{encoring} }
